/**
 * A button to download a file from the server
 *
 */
Ext.define('App.button.Download', {

    extend: 'Ext.button.Button',
    alias: 'widget.xbuttondownload',

    /**
     * @cfg{String}
     * The URL of the server controller returning the file.
     */
    url: undefined,

     // private method requests by the component model of ExtJS
    initComponent: function () {

        // initialize the base class
        this.callParent(arguments);

        // download when the button is pressed
        this.on('click', this.onDownload, this);
    },

    /**
     * Handler to download the file
     * The scope is the button.
     *
     * **Note:** the method add and iframe at the end of the DOM document
     * the source of the iframe is the URL pointing to the server controller.
     * The latter return a document which is automatically loaded.
     *
     * Method suggested on the
     * [sencha forum](http://www.sencha.com/forum/showthread.php?26471-Download-File-on%28-click-%29).
     *
     * @param {Ext.Button} button
     * @param {Ext.EventObject} event
     */
    onDownload: function (button, event) {

        "use strict";

        // remove existing iframe
        try {
            Ext.destroy(Ext.get('downloadIframe'));
        } catch (ignore) {}

        // create a fresh iframe
        Ext.DomHelper.append(document.body, {
            tag: 'iframe',
            id: 'downloadIframe',
            frameBorder: 0,
            width: 0,
            height: 0,
            css: 'display:none;visibility:hidden;height:0px;',
            src: this.url
        });
    }
});