/**
 * The field AceEditor is a wrapping of the
 * [ACE editor](http://http://ace.c9.io/#nav=about)
 * It can be embedded in Ext.form.Panel.
 *
 * @since 0.4.15.0
 *
 */
Ext.define('App.form.field.AceEditor', {

    extend: 'Ext.form.FieldContainer',
    mixins: {
        field: 'Ext.form.field.Field'
    },
    alias: 'widget.xaceeditorfield',

    /**
     * @cfg {Number}
     * The font size in pixels
     */
    fontSize: 10,

    /**
     * @cfg {String}
     * The programming language javascript, python, ....
     */
    language: 'python',

    /**
     * @cfg {Number} editorHeight (required)
     * The height of the editor widget
     */
    editorHeight: 150,

    /**
     * @cfg {String}
     */
    theme: 'crimson_editor',

    // private property
    editor: null,
    panel: null,
    valueBeforeRender: undefined,

    // private method requests by the component model of ExtJS
    initComponent: function (config) {

        var me = this;

        me.items = [{
            frame: true,
            height: me.editorHeight,
            xtype: 'panel'
        }];

        me.callParent(arguments);
        me.panel = me.child('panel');

        me.panel.on('afterrender', me.addEditor, me);

        me.initField();
    },

    // private method requests by the component model of ExtJS
    beforeDestroy: function () {

        var me = this;

        me.panel.un('afterrender', me.addEditor, me);

        me.editor.destroy();
        Ext.destroyMembers(me, 'editor');

        me.callParent(arguments);
    },

    // private to embed the ace editor inside the panel
    addEditor: function () {

        "use strict";
        var me = this;

        // instantiate the editor
        me.editor = ace.edit(me.panel.getId());
        me.editor.getSession().setMode('ace/mode/' + me.language);
        me.editor.setFontSize(me.fontSize);

        if (me.theme) {
            me.editor.setTheme('ace/theme/' + me.theme);
        }

        // load the value
        me.editor.setValue(me.valueBeforeRender);
        me.editor.clearSelection();
        me.editor.moveCursorTo(0, 0);
    },

    /**
     * Return the value of this field.
     *
     * @return {String}
     *
     */
    getValue: function () {

        "use strict";
        var me = this;

        if (me.editor) {
            return me.editor.getValue();
        }

        return undefined;
    },

    /**
     * Set the value for this field.
     *
     * @param {String} value
     *
     */
    setValue: function (value) {

        "use strict";
        var me = this;

        if (me.editor) {
            me.editor.setValue(value);
            me.editor.clearSelection();
            me.editor.moveCursorTo(0, 0);

            me.valueBeforeRender = undefined;

        // Keep track of the value.
        // It will be used at the first rendering of the editor
        } else {
            me.valueBeforeRender = value;
        }

        // the standard way to set the value for a field
        // extract from Ext.form.field.Base
        return me.mixins.field.setValue.call(me, value);
    }
});