/**
 * This is Ext.form.field.ComboBox linked to a database table.
 *
 * The store attribute is equal the table name when the widget
 * is configured. It is replaced by an App.data.DirectStore
 * in the initialization phase of the component.
 *
 */
Ext.define('App.form.field.ComboBox', {

    extend: 'Ext.form.field.ComboBox',
    alias: 'widget.xcombobox',

    /**
     * @cfg {Boolean}
     * Select the first element of the store when true.
     *
     * **Note**: This configuration parameter works well when the ComboBox
     * is embedded in a selector but failed when it is embedded in a form.
     * For the latter case define the ''default'' value when defining
     * the database model.
     *
     */
    selectFirst: false,

    // Predefined setting
    // Works in auto completion mode when the user type value.
    // In any case the value should belongs to the list.
    editable: true,
    forceSelection: true,
    queryMode: 'local',
    triggerAction: 'all',

    // private properties for internationalization
    textSelect: 'Select a ',

    // private method require by the ExtJs component model
    initComponent: function () {

        // defined the empty text from the field label
        if (this.fieldLabel && !this.emptyText) {
            this.emptyText = this.textSelect + this.fieldLabel + " ...";
        }

        // link the ComboBox to the data store
        // load the store if not yet done
        this.store = App.getStore(this.store);

        if (this.store.getCount() === 0) {
            this.store.load();
        }

        // initialise the base class
        this.callParent(arguments);

        // select the first value
        if (this.selectFirst) {
            this.on('afterrender', this.selectFirstItem, this);
        }
    },

    // private method requires by the ExtJs component model
    beforeDestroy: function () {

        if (this.selectFirst) {
            this.un('afterrender', this.selectFirstItem, this);
        }

        this.callParent(arguments);
    },

    // private method to select the first item in the store
    selectFirstItem: function () {

        "use strict";

        var record;

        // the store is not ready, reschedule the request
        if (!this.store.getCount()) {
            this.store.on('load', this.selectFirstItem, this, {single: true});
            return;
        }

        record = this.store.getAt(0);
        this.setValue(record.get(this.valueField));
    }
});