/**
 * Base class to export the content of a App.grid.Panel.
 *
 * @since 0.6.2
 *
 */
Ext.define('App.grid.mixin.ExportBase', {

    //
    // Get the label and the alignment of the visible columns.
    //
    // @return {Object}
    // @return {String[]} return.alignments
    // @return {Boolean}  return.hidden
    // @return {String[]} return.labels empty for hidden headers
    //
    //
    getColumnHeader: function () {

        "use strict";

        var me = this,
            alignments = [],
            columns,
            container,
            i,
            label,
            labels = [];

        container = me.getDockedItems('headercontainer');

        if (container.length) {
            columns = container[0].getVisibleGridColumns();

            for (i = 0; i < columns.length; i += 1) {

                // the label of the RowNumberer column is a non breaking space
                // replace it by an empty space to avoid crash in latex processing
                label = columns[i].text;
                if (label === "&#160") {
                    label = "";
                }
                labels.push(label);

                if (columns[i].align) {
                    alignments.push(columns[i].align);
                } else {
                    alignments.push('left');
                }
            }
        }

        return {
            alignments: alignments,
            hidden: container[0].isHidden(),
            labels: labels
        };
    }
});