/**
 * The plugin to handle Ext.ComponentLoader exception
 *
 * @since 0.6.0.0
 *
 */
Ext.define('App.panel.plugin.LoaderException', {

    extend: 'Ext.AbstractPlugin',
    alias: 'plugin.pPanelLoaderException',

    // Private attribute for internationalization
    textError: 'Error  ...',

    /**
     * Initialize the plugin
     *
     * @param {Ext.Panel} panel
     */
    init: function (panel) {

        "use strict";

        this.setCmp(panel);
        panel.getLoader().on('exception', this.onLoaderFailure, this);
    },

    /**
     * Destroy the plugin
     */
    destroy: function () {

        "use strict";
        this.getCmp().getLoader().un('exception', this.onLoaderFailure, this);
    },

    /**
     * Handler call when the procedure loading the panel failed.
     *
     * @param {Ext.ComponentLoader} loader
     * @param {Object} response
     * @param {Object} options
     */
    onLoaderFailure: function (loader, response, options) {

        "use strict";

        if (response.statusText) {
            Ext.Msg.show({
                title: this.textError,
                msg: response.statusText,
                buttons: Ext.Msg.OK,
                icon: Ext.Msg.WARNING
            });
        }
    }
});
